FlutterImageCompressWeb class
- Inheritance
-
- Object
- PlatformInterface
- FlutterImageCompressPlatform
- FlutterImageCompressWeb
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
validator
→ FlutterImageCompressValidator
-
no setteroverride
Methods
-
compressAndGetFile(String path, String targetPath, {int minWidth = 1920, int minHeight = 1080, int inSampleSize = 1, int quality = 95, int rotate = 0, bool autoCorrectionAngle = true, CompressFormat format = CompressFormat.jpeg, bool keepExif = false, int numberOfRetries = 5})
→ Future<XFile?>
-
override
-
compressAssetImage(String assetName, {int minWidth = 1920, int minHeight = 1080, int quality = 95, int rotate = 0, bool autoCorrectionAngle = true, CompressFormat format = CompressFormat.jpeg, bool keepExif = false})
→ Future<Uint8List?>
-
override
-
compressWithFile(String path, {int minWidth = 1920, int minHeight = 1080, int inSampleSize = 1, int quality = 95, int rotate = 0, bool autoCorrectionAngle = true, CompressFormat format = CompressFormat.jpeg, bool keepExif = false, int numberOfRetries = 5})
→ Future<Uint8List?>
-
override
-
compressWithList(Uint8List image, {int minWidth = 1920, int minHeight = 1080, int quality = 95, int rotate = 0, int inSampleSize = 1, bool autoCorrectionAngle = true, CompressFormat format = CompressFormat.jpeg, bool keepExif = false})
→ Future<Uint8List>
-
override
-
ignoreCheckSupportPlatform(bool bool)
→ void
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
showNativeLog(bool value)
→ Future<void>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited